function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var dateFns = require('date-fns');
var React = require('react');
var React__default = _interopDefault(React);

var styles = {"root":"_3HH92"};

var ChronoUnitStack = function ChronoUnitStack(props) {
  var items = props.items,
      unit = props.unit,
      value = props.value,
      onChange = props.onChange;
  var rootRef = React.createRef();
  React.useEffect(function () {
    if (value !== undefined) {
      var node = rootRef.current.querySelector("#" + unit + "-" + value);
      node === null || node === void 0 ? void 0 : node.scrollIntoView();
      rootRef.current.scrollBy({
        top: -rootRef.current.clientHeight * 0.33
      });
    }
  }, []);
  var handleValueChange = React.useCallback(function (item) {
    onChange && onChange(unit, item.value);
  }, [onChange]);
  return React__default.createElement("div", {
    ref: rootRef,
    className: styles.root
  }, items.map(function (item) {
    return React__default.createElement("div", {
      key: unit + ":" + item.value
    }, React__default.createElement("button", {
      id: unit + "-" + item.value,
      onClick: function onClick() {
        return handleValueChange(item);
      },
      className: toItemButtonclasses(item, value).join(" ")
    }, item.label));
  }));
};

function toItemButtonclasses(item, value) {
  return ["btn", "btn-block"].concat(item.value == value ? "btn-primary" : "btn-outline-primary");
}

function yearsStack() {
  var currentYear = dateFns.getYear(new Date());
  var arr = [];

  for (var index = -50; index < 10; index++) {
    var year = currentYear + index;
    arr.push({
      value: year,
      label: year.toString()
    });
  }

  return arr;
}
function monthsStack(tr) {
  var arr = [];

  for (var index = 0; index < 12; index++) {
    arr.push({
      value: index,
      label: tr({
        type: "month",
        value: index
      })
    });
  }

  return arr;
}
function hoursStack() {
  var arr = [];

  for (var index = 0; index < 24; index++) {
    arr.push({
      label: index.toString().padStart(2, "0"),
      value: index
    });
  }

  return arr;
}
function minutesStack() {
  var arr = [];

  for (var index = 0; index < 60; index++) {
    arr.push({
      label: index.toString().padStart(2, "0"),
      value: index
    });
  }

  return arr;
}
function translateMonth(locale, index) {
  return new Intl.DateTimeFormat(locale, {
    month: "long"
  }).format(new Date(2020, index, 1));
}

var styles$1 = {"container":"_28D6g","localdateContainer":"_1Hmqn","localdatetimeContainer":"_3PKA7"};

var DatePickerControlsContainer = function DatePickerControlsContainer(props) {
  var type = props.type,
      children = props.children;
  var containerClasses = [styles$1.container, type === "localdatetime" ? styles$1.localdatetimeContainer : styles$1.localdateContainer];
  return React__default.createElement("div", {
    className: containerClasses.join(" ")
  }, children);
};

var styles$2 = {"monthCalendarGrid":"_1XpeP","dayOfMonthButton":"_21Z3U","dayOfMonthGhostButton":"_hmUPI","dayOfMonthCelebration":"_3ZC0z","btn-primary":"_23bJZ"};

var DaysOfMonthCalendar = function DaysOfMonthCalendar(props) {
  var month = props.month,
      year = props.year,
      tr = props.tr,
      value = props.value,
      onChange = props.onChange;

  var _useMemo = React.useMemo(function () {
    return toDaysInMonth(year, month);
  }, [year, month]),
      allDays = _useMemo.allDays;

  return React__default.createElement("div", {
    className: styles$2.monthCalendarGrid
  }, [0, 1, 2, 3, 4, 5, 6].map(function (dayOfWeek) {
    return React__default.createElement("div", {
      key: "dayOfWeek:" + dayOfWeek
    }, tr({
      type: "dayOfWeek",
      value: dayOfWeek
    }));
  }), allDays.map(function (day, i) {
    return React__default.createElement("div", {
      key: "day:" + i
    }, React__default.createElement("button", {
      tabIndex: -1,
      disabled: isDateButtonDisabled(day, [year, month]),
      onClick: function onClick() {
        return onChange("dayOfMonth", dateFns.getDate(day));
      },
      className: ["btn", styles$2.dayOfMonthButton, value === dateFns.getDate(day) && dateFns.getMonth(day) === month ? "btn-primary" : styles$2.dayOfMonthGhostButton].join(" ")
    }, dateFns.getDate(day)));
  }));
};

function toDaysInMonth(year, month) {
  var startOfTheMonth = dateFns.startOfMonth(new Date(year, month));
  var daysInMonth = dateFns.getDaysInMonth(startOfTheMonth);
  var dayOffset = dateFns.getDay(startOfTheMonth) - 1 === -1 ? 6 : dateFns.getDay(startOfTheMonth) - 1;
  var allDays = [];

  for (var i = 0; i < 42; i++) {
    allDays.push(dateFns.addDays(startOfTheMonth, i - dayOffset));
  }

  return {
    allDays: allDays,
    daysInMonth: daysInMonth
  };
}

function isDateButtonDisabled(date, _ref) {
  var year = _ref[0],
      month = _ref[1];
  var monthStart = dateFns.startOfMonth(new Date(year, month));
  var monthEnd = dateFns.endOfMonth(new Date(year, month));
  return dateFns.isAfter(date, monthEnd) || dateFns.isBefore(date, monthStart);
}

function toDayOfWeek(locale, index) {
  var weekday = [new Date("2020-01-06"), new Date("2020-01-07"), new Date("2020-01-08"), new Date("2020-01-09"), new Date("2020-01-10"), new Date("2020-01-11"), new Date("2020-01-12")];
  return new Intl.DateTimeFormat(locale, {
    weekday: "short"
  }).format(weekday[index]);
}

var defaultTranslations = function defaultTranslations(locale) {
  var headersTranslations = {
    year: {
      hr: "Godina",
      en: "Year",
      pl: "Rok"
    },
    month: {
      hr: "Mjesec",
      en: "Year",
      pl: "Miesiąc"
    },
    dayOfMonth: {
      hr: "Dan u mjesecu",
      en: "Day of month",
      pl: "Dzień miesiąca"
    },
    hour: {
      hr: "Čas",
      en: "Hour",
      pl: "Godzina"
    },
    minute: {
      hr: "Minuta",
      en: "Minute",
      pl: "Minuta"
    }
  };
  return function (item) {
    if (item.type === "dayOfWeek") {
      return toDayOfWeek(locale, item.value);
    }

    if (item.type === "month") {
      return translateMonth(locale, item.value);
    }

    if (item.type === "chronoUnitHeader") {
      var translations = headersTranslations[item.value];

      if (!translations) {
        return "??" + item + "??";
      }

      var translation = translations[locale.substring(0, 2)];

      if (!translation) {
        return "??" + item + "??";
      }

      return translation;
    }

    return "??" + item + "??";
  };
};

var styles$3 = {"root":"_383sa"};

var DatePicker = function DatePicker(props) {
  var open = props.open,
      _props$type = props.type,
      type = _props$type === void 0 ? "localdatetime" : _props$type;

  var _useDatePickerInterna = useDatePickerInternals(props),
      tr = _useDatePickerInterna.tr,
      years = _useDatePickerInterna.years,
      months = _useDatePickerInterna.months,
      hours = _useDatePickerInterna.hours,
      minutes = _useDatePickerInterna.minutes,
      currentYear = _useDatePickerInterna.currentYear,
      currentMonth = _useDatePickerInterna.currentMonth,
      currentDay = _useDatePickerInterna.currentDay,
      currentHour = _useDatePickerInterna.currentHour,
      currentMinute = _useDatePickerInterna.currentMinute,
      handleChronoUnitChange = _useDatePickerInterna.handleChronoUnitChange,
      handleKeyDown = _useDatePickerInterna.handleKeyDown;

  if (open === false) {
    return null;
  }

  return React__default.createElement("div", {
    tabIndex: -1,
    onKeyDown: handleKeyDown,
    className: ["card", styles$3.root].join(" ")
  }, React__default.createElement("div", {
    className: "card-body"
  }, React__default.createElement(DatePickerControlsContainer, {
    type: type
  }, React__default.createElement("h6", null, tr({
    type: "chronoUnitHeader",
    value: "year"
  })), React__default.createElement("h6", null, tr({
    type: "chronoUnitHeader",
    value: "month"
  })), React__default.createElement("h6", null, tr({
    type: "chronoUnitHeader",
    value: "dayOfMonth"
  })), type === "localdatetime" && React__default.createElement(React__default.Fragment, null, React__default.createElement("h6", null, tr({
    type: "chronoUnitHeader",
    value: "hour"
  })), React__default.createElement("h6", null, tr({
    type: "chronoUnitHeader",
    value: "minute"
  }))), React__default.createElement(ChronoUnitStack, {
    value: currentYear,
    onChange: handleChronoUnitChange,
    items: years,
    unit: "year"
  }), React__default.createElement(ChronoUnitStack, {
    value: currentMonth,
    onChange: handleChronoUnitChange,
    items: months,
    unit: "month"
  }), React__default.createElement(DaysOfMonthCalendar, {
    value: currentDay,
    onChange: handleChronoUnitChange,
    tr: tr,
    year: currentYear,
    month: currentMonth
  }), type === "localdatetime" && React__default.createElement(React__default.Fragment, null, React__default.createElement(ChronoUnitStack, {
    value: currentHour,
    onChange: handleChronoUnitChange,
    items: hours,
    unit: "hour"
  }), React__default.createElement(ChronoUnitStack, {
    value: currentMinute,
    onChange: handleChronoUnitChange,
    items: minutes,
    unit: "minute"
  })))));
};
function useDatePickerInternals(props) {
  var value = props.value,
      open = props.open,
      onClose = props.onClose,
      onChange = props.onChange,
      type = props.type;
  var tr = React.useMemo(function () {
    if (props.tr) return props.tr;

    if (props.locale) {
      return defaultTranslations(props.locale);
    }

    throw new Error("Both locale and tr properties are missing");
  }, [props.locale, props.tr]);
  var years = React.useMemo(yearsStack, []);
  var months = React.useMemo(function () {
    return monthsStack(tr);
  }, []);
  var hours = React.useMemo(hoursStack, []);
  var minutes = React.useMemo(minutesStack, []);
  var currentDate = React.useMemo(function () {
    return !!value ? new Date(value) : new Date();
  }, [value]);

  var _useMemo = React.useMemo(function () {
    var currentYear = dateFns.getYear(currentDate);
    var currentMonth = dateFns.getMonth(currentDate);
    var currentDay = dateFns.getDate(currentDate);
    var currentHour = dateFns.getHours(currentDate);
    var currentMinute = dateFns.getMinutes(currentDate);
    return {
      currentYear: currentYear,
      currentMonth: currentMonth,
      currentDay: currentDay,
      currentHour: currentHour,
      currentMinute: currentMinute
    };
  }, [currentDate]),
      currentYear = _useMemo.currentYear,
      currentMonth = _useMemo.currentMonth,
      currentDay = _useMemo.currentDay,
      currentHour = _useMemo.currentHour,
      currentMinute = _useMemo.currentMinute;

  var handleChronoUnitChange = React.useCallback(function (unit, unitValue) {
    if (!onChange) {
      return;
    }

    var updatedDate = function () {
      switch (unit) {
        case "year":
          {
            return dateFns.setYear(currentDate, unitValue);
          }

        case "month":
          {
            return dateFns.setMonth(currentDate, unitValue);
          }

        case "dayOfMonth":
          {
            return dateFns.setDate(currentDate, unitValue);
          }

        case "hour":
          {
            return dateFns.setHours(currentDate, unitValue);
          }

        case "minute":
          {
            return dateFns.setMinutes(currentDate, unitValue);
          }

        default:
          throw new Error();
      }
    }();

    onChange(type === "localdate" ? updatedDate.toISOString().substring(0, 10) : updatedDate.toISOString());
  }, [onChange, currentDate]);
  var handleKeyDown = React.useCallback(function (e) {
    if (e.key === "Escape") {
      onClose && onClose();
    }
  }, []);
  React.useEffect(function () {
    if (open === true && !!onClose) {
      var listener = function listener() {
        onClose();
        window.removeEventListener("click", listener);
      };

      window.addEventListener("click", listener);
    }
  }, [onClose, open]);
  return {
    tr: tr,
    years: years,
    months: months,
    hours: hours,
    minutes: minutes,
    currentYear: currentYear,
    currentMonth: currentMonth,
    currentDay: currentDay,
    currentHour: currentHour,
    currentMinute: currentMinute,
    handleChronoUnitChange: handleChronoUnitChange,
    handleKeyDown: handleKeyDown
  };
}
function useDatePickerContainer(onClose) {
  var ref = React.createRef();
  return React.useMemo(function () {
    function handleOnBlur() {
      var nodeWithin = ref.current.parentNode.querySelector(":focus-within");
      var anyNode = document.body.querySelector(":focus-within");

      if (!!nodeWithin) {
        return;
      }

      if (!!anyNode && !!anyNode.localName) {
        onClose();
      }
    }

    return {
      containerRef: ref,
      onBlur: handleOnBlur,
      onClick: function onClick(e) {
        return e.stopPropagation();
      }
    };
  }, [ref]);
}

exports.ChronoUnitStack = ChronoUnitStack;
exports.DatePicker = DatePicker;
exports.DatePickerControlsContainer = DatePickerControlsContainer;
exports.DaysOfMonthCalendar = DaysOfMonthCalendar;
exports.defaultTranslations = defaultTranslations;
exports.hoursStack = hoursStack;
exports.minutesStack = minutesStack;
exports.monthsStack = monthsStack;
exports.toDayOfWeek = toDayOfWeek;
exports.translateMonth = translateMonth;
exports.useDatePickerContainer = useDatePickerContainer;
exports.useDatePickerInternals = useDatePickerInternals;
exports.yearsStack = yearsStack;
//# sourceMappingURL=index.js.map
